#!/bin/bash
# http://traverso-daw.org
#
REPO=http://zenwalk.pinguix.com/user-accounts/tilderb/extra/xap/traverso

# script by til <rob DOT til DOT freedman AT googlemail DOT com>
#
set -x -u -e

# traverso
version='0.49.2'
build=${build:-'66.1'}

#arch=native
#tune=

arch=${arch:-i686}
#tune=${tune:-i686}
tune=${tune:-pentium-m}
#tune=${tune:-native}

pkgname=traverso-$version
package=traverso-${version}-$arch-$build

PKG_DEP="alsa-lib,curl,cxxlibs,cyrus-sasl,db44,expat,fftw,flac,fontconfig,freetype,gcc,gcc-g++,glib2,gmp,jack,krb5,lame,libidn,libmad,libogg,libpng,libsamplerate,libsndfile,libvorbis,libxml2,libxslt,mpfr,openldap-client,openssl,raptor,redland,slv2,wavpack,xcb,xorg-libs,zlib"

PKG_SRC="http://traverso-daw.org/download.html&d=$pkgname.tar.gz
$REPO/build-traverso.sh"

# call from empty dir to force download
#for url in $PKG_SRC;do zw="${url##*=}"; [ ! -e ${zw##*/} ] && wget -n $url; done

# build root
CWD=`pwd`
TMP=$CWD/tmp
PKG=$TMP/$package
SRC=$TMP/$pkgname
#
[ -d $TMP ] && rm -fr $TMP

mkdir -p $PKG/install
mkdir -p $PKG/usr/{doc,src}/$pkgname
mkdir -p $PKG/usr/share/{traverso,applications,mime/packages,mimelnk/application,icons/hicolor}

# Extract the source archive
tar xzf $CWD/$pkgname.tar.gz -C $TMP
cd $SRC

export QTDIR=/usr/lib/qt
export PATH=/usr/lib/qt4/bin:$PATH

# use for optimized local build:
# -DDETECT_HOST_CPU_FEATURES=ON
# -DCMAKE_C_FLAGS="-DARCH_X86 -DSSE_OPTIMIZATIONS -msse -mfpmath=sse -DUSE_XMMINTRIN -march=i686 -mtune=$tune" 

# use 'slv2' instead of 'libslv2' in 'PKG_CHECK_MODULES()'
# patch -p0 -i $CWD/CMakeLists-slv2.patch
sed -i "s@SLV2  libslv2>=@SLV2  slv2>=@" CMakeLists.txt

cmake . \
  -DCMAKE_INSTALL_PREFIX=/usr \
  -DUSE_SYSTEM_SLV2_LIBRARY=ON \
  -DCMAKE_VERBOSE_MAKEFILE=TRUE \
  -DDETECT_HOST_CPU_FEATURES=OFF \
  -DCMAKE_CXX_FLAGS="-DARCH_X86 -DSSE_OPTIMIZATIONS -DUSE_XMMINTRIN -march=i686 -mtune=$tune " \
  -DWANT_MP3_ENCODE=ON \
  -DWANT_MP3_DECODE=ON \
  -DWANT_PORTAUDIO=ON \
  -DWANT_JACK=ON \

make || exit
make DESTDIR=$PKG install

# desktop files
( cd resources
  cp traverso.desktop $PKG/usr/share/applications/traverso.desktop
  cp -r freedesktop/icons/{16x16,24x24,48x48,scalable} $PKG/usr/share/icons/hicolor/
  cp -r --parents translations/*.qm $PKG/usr/share/traverso
  cp -r --parents themes $PKG/usr/share/traverso
)
# x-traverso.xml
cat <<EOF >$PKG/usr/share/mime/packages/x-traverso.xml
<?xml version="1.0" encoding="UTF-8"?>
<mime-info xmlns="http://www.freedesktop.org/standards/shared-mime-info">
  <mime-type type="application/x-traverso">
    <sub-class-of type="text/xml"/>
    <comment>Traverso Project</comment>
    <glob pattern="*.tpf"/>
  </mime-type>
</mime-info>
EOF
# x-traverso.desktop
cat <<EOF >$PKG/usr/share/mimelnk/application/x-traverso.desktop
[Desktop Entry]
Encoding=UTF-8
Comment=Traverso Project
Type=MimeType
MimeType=application/x-traverso
Patterns=*.tpf
Icon=gnome-mime-application-x-traverso
X-KDE-AutoEmbed=false
EOF

# docs
echo "http://traverso-daw.org/
http://traverso-daw.org/UserManual.html" \
 > $PKG/usr/doc/$pkgname/traverso-manuals.url

gzip -c9 COPYING >$PKG/usr/doc/$pkgname/COPYING.gz
cp AUTHORS COPYRIGHT ChangeLog HISTORY README TODO $PKG/usr/doc/$pkgname

# strip symbols
find $PKG | xargs file | grep "executable" | grep ELF | cut -f 1 -d : |\
  xargs strip --verbose --strip-unneeded 2> /dev/null

# slack-desc
#        |----handy-ruler------------------------------------------------------|
cat <<EOF > $PKG/install/slack-desc
traverso: traverso (multitrack audio editor)
traverso:
traverso: A free, cross platform multitrack audio recording and editing suite,
traverso: with an innovative and easy to master User Interface.
traverso:
traverso: It's suited for both the professional and home user,
traverso: who needs a robust and solid DAW.
traverso:
EOF
cp $CWD/build-traverso.sh $PKG/usr/src/$pkgname

# done so far, make package
cd $PKG
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz

cd $CWD
echo "$PKG_SRC" >$package.src
echo -n $PKG_DEP >$package.dep
md5sum $package.txz > $package.md5

# cleanup
#rm -rf $TMP
